import requests
from requests.adapters import HTTPAdapter
from urllib3.util import Retry
import json
from RupineHeroku.rupine_db import herokuDbAccess

def getToken(connection, schema, chain_id, token_address):
    
    sql = "SELECT * FROM %s.token WHERE chain_id = %s AND token_address = '%s';"
    
    result = herokuDbAccess.fetchDataInDatabase(sql, [schema,chain_id,token_address], connection)    
    return result[0][0]

def getTokenWithoutName(connection, schema, chain_id, gteCreatedAt):
    
    sql = "SELECT * FROM %s.evm_token WHERE chain_id = %s AND name = 'n/a' AND created_at >= %s"
    
    result = herokuDbAccess.fetchDataInDatabase(sql, [schema,chain_id,gteCreatedAt], connection)    
    return result[0][0]


from RupineHeroku.rupine_db import herokuDbAccess

def postTaxTransaction(connection, schema, data):

    sql = "INSERT INTO {0}.tax_transaction (chain_id,chain,public_address,timestamp,block_number,transaction_hash,category,token,amount,usd_value,eur_value) \
        VALUES ({1},{2},{3},{4},{5},{6},{7},{8},{9},{10},{11})".format(
        schema,
        data['chain_id'],
        data['chain'],
        data['public_address'],
        data['timestamp'],
        data['block_number'],
        data['transaction_hash'],
        data['category'],
        data['token'],
        data['amount'],
        data['usd_value'],
        data['eur_value']
    )

    result = herokuDbAccess.insertDataIntoDatabase(sql, connection)    
    return result[0][0]

def postTaxReward(connection, schema, data):

    sql = "INSERT INTO {0}.tax_transaction (chain_id,chain,public_address,timestamp,block_number,transaction_hash,category,token,amount,usd_value,eur_value) \
        VALUES ({1},{2},{3},{4},{5},{6},{7},{8},{9},{10},{11})".format(
        schema,
        data['chain_id'],
        data['chain'],
        data['public_address'],
        data['timestamp'],
        data['category'],
        data['token'],
        data['amount'],
        data['usd_value'],
        data['eur_value']
    )

    result = herokuDbAccess.insertDataIntoDatabase(sql, connection)    
    return result[0][0]